@@ -6,6 +6,10 @@ from nose.tools import *
 from ikazuchi.core.translator import TranslatingGoogle
 
 class TestGoogleTranslator(object):
+    """
+    Do not test to request actually since Google Translate API v2 is
+    a paid service from 2011/12/1
+    """
 
     def setup(self):
         self.t = TranslatingGoogle("ja", "en", None)
@@ -16,10 +20,12 @@ class TestGoogleTranslator(object):
         expected = "https://www.googleapis.com/language/translate/v2/detect"
         assert_equal(expected, self.t.get_url(detect))
 
+    @nottest
     def test_detect(self):
         res = self.t.detect([unicode("テスト", "utf-8")])
         assert_equal(u"ja", res[1][0][0][u"language"])
 
+    @nottest
     def test_translate(self):
         assert_equal(('Google', [u'Test']),
                      self.t.translate([unicode("テスト", "utf-8")]))
